@@ -548,7 +548,7 @@ def fc_host_transport_type(scsi_host_id):
             return "FCoE"
 
     if "driver" in list(host_info.keys()):
-        if host_info["driver"] == "bnx2fc":
+        if host_info["driver"] in ["bnx2fc", "qedf"]:
             return "FCoE"
 
     _print("DEBUG: Could not figure out if controller %s is FC or FCoE" % scsi_host_id)
