@@ -28,10 +28,11 @@ import errno
 import time
 import subprocess
 import requests
+import augeas
 import re  # regex
 import libsan.host.mp
 import libsan.host.scsi
-from libsan.host.cmdline import run
+from libsan.host.cmdline import run, exists
 from datetime import datetime
 from os import listdir
 from pkg_resources import parse_version
@@ -230,6 +231,33 @@ def service_restart(service_name):
     return True
 
 
+def service_enable(service_name):
+    """
+    Enable service
+    The arguments are:
+    \tName of the service
+    Returns:
+    \tTrue: Service got enabled
+    \tFalse: There was some problem
+    """
+    cmd = "systemctl enable %s" % service_name
+    has_systemctl = True
+
+    if run("which systemctl", verbose=False) != 0:
+        has_systemctl = False
+    if not has_systemctl:
+        cmd = "chkconfig %s stop" % service_name
+
+    retcode = run(cmd, return_output=False, verbose=True)
+    if retcode != 0:
+        _print("FAIL: Could not enable %s" % service_name)
+        if has_systemctl:
+            run("systemctl status %s" % service_name)
+            run("journalctl -xn")
+        return False
+    return True
+
+
 def service_status(service_name, verbose=True):
     """
     Check service status
@@ -338,7 +366,7 @@ def package_version(pkg):
     if not release:
         _print("FAIL: package_version() - Couldn't get release")
         return None
-    if release == "rhel" or release == "fedora":
+    if exists("rpm"):
         ret, output = run("rpm -qa --qf='%%{version}.%%{release}' %s" % pkg,
                           return_output=True, verbose=False)
         if ret != 0:
@@ -494,6 +522,19 @@ def sleep(duration):
     return
 
 
+def is_mounted(device=None, mountpoint=None):
+    """
+    Check if mountpoint is already mounted
+    """
+    if device:
+        if run("mount | grep %s" % device, verbose=False) != 0:
+            return False
+    if mountpoint:
+        if run("mount | grep %s" % mountpoint, verbose=False) != 0:
+            return False
+    return True
+
+
 def mount(device=None, mountpoint=None, fs=None, options=None):
     cmd = "mount"
     if fs:
@@ -515,13 +556,13 @@ def umount(device=None, mountpoint=None):
     cmd = "umount"
     if device:
         cmd += " %s" % device
-        if run("mount | grep %s" % device, verbose=False) != 0:
+        if not is_mounted(device):
             # Device is not mounted
             return True
 
     if mountpoint:
         cmd += " %s" % mountpoint
-        if run("mount | grep %s" % mountpoint, verbose=False) != 0:
+        if not is_mounted(mountpoint=mountpoint):
             # Device is not mounted
             return True
 
@@ -1293,7 +1334,7 @@ def download_repo_file(url, name=None, overwrite=True):
         else:
             print("WARN: %s exits, overwriting .repo file" % name)
     try:
-        r = requests.get(url)
+        r = requests.get(url, timeout=10)
     except requests.exceptions.RequestException as e:
         print("FAIL: Unable to reach repo url: %s" % e)
         return False
@@ -1452,3 +1493,50 @@ def get_system_logs(length=None, reverse=False, kernel_only=False, since=None, g
         line[3] = line[3].split(".")[0]
         data += " ".join(line) + "\n"
     return ret, data
+
+
+def aug_set_config(config_file, parameters):
+    """
+    Edit or create configuration files
+    Parameters:
+    \t config_file: path e.g. /etc/something/something.conf
+    \t parameters: dict e.g. {'IPADDR': '10.37.151.7', 'group_of_params/subparam': 'paramvalue'}
+
+    For complex configuration files, check Augeas lens documentation, or check the correct "path" using augeas match
+    Example:
+    $ cat /etc/krb5.conf
+    [logging]
+        default = FILE:/var/log/krb5libs.log
+
+    > aug.match('/files/etc/krb5.conf/logging/default/*')
+    ['/files/etc/krb5.conf/logging/default/file']
+    > aug.get('/files/etc/krb5.conf/logging/default/file')
+    '/var/log/krb5libs.log'
+
+    libsan.host.linux.set_config('/etc/krb5.conf', {'logging/default/file':'some/new/log/path.log'})
+    """
+
+    aug = augeas.Augeas()
+    path = '/files' + config_file + '/'
+    # Check if we can use augeas
+    if not aug.match(path + '*'):
+        print('FAIL: Augeas is not able to process {}'.format(path))
+        return False
+
+    if parameters is not None:
+        for key in parameters:
+            print("INFO: Setting '{}' to '{}' in {}".format(key, parameters[key], config_file))
+            aug.set(path + key, parameters[key])
+
+    try:
+        aug.save()
+    except IOError:
+        print('FAIL: unable to save changes in ' + config_file)
+        aug.close()
+        return False
+    except Exception as e:
+        print("FAIL: ", e)
+        aug.close()
+        return False
+    aug.close()
+    return True
