@@ -77,7 +77,7 @@ def pv_query(verbose=False):
     return pv_dict
 
 
-def pv_create(pv_name, options=None, verbose=True):
+def pv_create(pv_name: str, options="", verbose=True):
     """Create a Volume Group.
     The arguments are:
     \tPV name
@@ -86,8 +86,6 @@ def pv_create(pv_name, options=None, verbose=True):
     \t\tTrue if success
     \t'tFalse in case of failure
     """
-    if options is None:
-        options = ""
 
     if not pv_name:
         _print("FAIL: pv_create requires pv_name")
@@ -100,7 +98,7 @@ def pv_create(pv_name, options=None, verbose=True):
     return True
 
 
-def pv_remove(pv_name, force=None, verbose=True):
+def pv_remove(pv_name: str, force=None, verbose=True):
     """Delete a Volume Group.
     The arguments are:
     \tVG name
@@ -189,7 +187,7 @@ def vg_query(verbose=False):
     return vg_dict
 
 
-def vg_create(vg_name, pv_name, force=False, verbose=True):
+def vg_create(vg_name: str, pv_name: str, force=False, verbose=True):
     """Create a Volume Group.
     The arguments are:
     \tPV name
@@ -213,7 +211,7 @@ def vg_create(vg_name, pv_name, force=False, verbose=True):
     return True
 
 
-def vg_remove(vg_name, force=False, verbose=True):
+def vg_remove(vg_name: str, force=False, verbose=True):
     """Delete a Volume Group.
     The arguments are:
     \tVG name
@@ -265,7 +263,7 @@ def lv_show():
     return True
 
 
-def lv_query(options=None, verbose=False):
+def lv_query(options="", verbose=False):
     """Query Logical Volumes and return a dictonary with LV information for each LV.
     The arguments are:
     \toptions:  If not want to use default lvs output. Use -o for no default fields
@@ -315,7 +313,7 @@ def lv_query(options=None, verbose=False):
     return lv_list
 
 
-def lv_create(vg_name, lv_name, options="", verbose=True):
+def lv_create(vg_name: str, lv_name: str, options: list, verbose=True):
     """Create a Logical Volume.
     The arguments are:
     \tVG name
@@ -338,7 +336,7 @@ def lv_create(vg_name, lv_name, options="", verbose=True):
     return True
 
 
-def lv_info(lv_name, vg_name, options=None, verbose=False):
+def lv_info(lv_name: str, vg_name: str, options="", verbose=False):
     """
     Show information of specific LV
     """
@@ -358,7 +356,7 @@ def lv_info(lv_name, vg_name, options=None, verbose=False):
     return None
 
 
-def lv_activate(lv_name, vg_name, verbose=True):
+def lv_activate(lv_name: str, vg_name: str, verbose=True):
     """Activate a Logical Volume
     The arguments are:
     \tLV name
@@ -382,7 +380,7 @@ def lv_activate(lv_name, vg_name, verbose=True):
     return True
 
 
-def lv_deactivate(lv_name, vg_name, verbose=True):
+def lv_deactivate(lv_name: str, vg_name: str, verbose=True):
     """Deactivate a Logical Volume
     The arguments are:
     \tLV name
@@ -406,7 +404,7 @@ def lv_deactivate(lv_name, vg_name, verbose=True):
     return True
 
 
-def lv_remove(lv_name, vg_name, verbose=True):
+def lv_remove(lv_name: str, vg_name: str, verbose=True):
     """Remove an LV from a VG
     The arguments are:
     \tLV name
@@ -440,7 +438,7 @@ def lv_remove(lv_name, vg_name, verbose=True):
     return True
 
 
-def lv_convert(vg_name, lv_name, options, verbose=True):
+def lv_convert(vg_name: str, lv_name: str, options: list, verbose=True):
     """Change Logical Volume layout.
     The arguments are:
     \tVG name
@@ -468,7 +466,7 @@ def lv_convert(vg_name, lv_name, options, verbose=True):
     return True
 
 
-def lv_extend(vg_name, lv_name, options, verbose=True):
+def lv_extend(vg_name: str, lv_name: str, options: list, verbose=True):
     """Increase size of logical volume.
     The arguments are:
     \tVG name
@@ -496,6 +494,34 @@ def lv_extend(vg_name, lv_name, options, verbose=True):
     return True
 
 
+def lv_reduce(vg_name: str, lv_name: str, options: list, verbose=True):
+    """Decrease size of logical volume.
+    The arguments are:
+    \tVG name
+    \tLV name
+    \toptions
+    Returns:
+    \tBoolean:
+    \t\tTrue if success
+    \t'tFalse in case of failure
+    """
+    if not options:
+        _print("FAIL: lv_reduce requires at least some options specified.")
+        return False
+
+    if not lv_name or not vg_name:
+        _print("FAIL: lv_reduce requires vg_name and lv_name")
+        return False
+
+    cmd = "lvreduce %s %s/%s" % (" ".join(options), vg_name, lv_name)
+    retcode = run(cmd, verbose=verbose)
+    if retcode != 0:
+        _print("FAIL: Could not reduce %s" % lv_name)
+        return False
+
+    return True
+
+
 ###########################################
 # Config file
 ###########################################
@@ -505,7 +531,7 @@ def get_config_file_path():
     return "/etc/lvm/lvm.conf"
 
 
-def update_config(key, value):
+def update_config(key: str, value: str):
     config_file = get_config_file_path()
     search_regex = re.compile(r"(\s*)%s(\s*)=(\s*)\S*" % key)
     search_regex_with_comment = re.compile(r"(\s*#\s*)%s(\s*)=(\s*)\S*" % key)
