@@ -755,10 +755,14 @@ def get_free_mpaths(exclude_boot_device=True, exclude_lvm_device=True):
 
         # Skip if it is used by LVM
         if pvs and exclude_lvm_device:
+            mp_used_by_lvm = False
             for pv in list(pvs.keys()):
                 if mpath_device_2_mpath_name(pv) == mp_info["mpath_name"]:
+                    mp_used_by_lvm = True
                     _print("DEBUG: get_free_mpaths() - skip %s as it is used for LVM" % mp_info["mpath_name"])
                     continue
+            if mp_used_by_lvm:
+                continue
 
         choosed_mpaths[mp_info["mpath_name"]] = mp_info
 
