@@ -19,7 +19,6 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 """net.py: Module to manipulate network devices."""
 
 import re  # regex
-import augeas
 import os.path
 import netifaces
 import ipaddress
@@ -27,6 +26,7 @@ import libsan.host.linux
 from os import listdir, readlink
 from os.path import join, lexists
 from libsan.host.cmdline import run
+from libsan.host.cmdline import exists
 
 __author__ = "Bruno Goncalves"
 __copyright__ = "Copyright (c) 2016 Red Hat, Inc. All rights reserved."
@@ -297,7 +297,7 @@ def convert_netmask(netmask='255.255.255.0'):
 
 def if_down(nic_or_mac):
     """
-    Bring the interface down
+    Bring the interface down using ifdown tool
     Parameters:
     \t Interface name or it's MAC address
     """
@@ -305,6 +305,12 @@ def if_down(nic_or_mac):
         _print("FAIL: if_down() - requires nic or mac as argument")
         return None
 
+    # ifup/ifdown scripts are not shipped by default on RHEL-8+
+    if not exists('ifdown') and libsan.host.linux.is_installed('NetworkManager'):
+        if not libsan.host.linux.install_package('NetworkManager-initscripts-updown'):
+            print('FAIL: unable to run "ifdown" command')
+            return False
+
     if is_mac(nic_or_mac):
         nic = get_nic_of_mac(nic_or_mac)
     else:
@@ -317,7 +323,7 @@ def if_down(nic_or_mac):
 
 def if_up(nic_or_mac):
     """
-    Bring the interface up
+    Bring the interface up using ifup tool
     Parameters:
     \t Interface name or it's MAC address
     """
@@ -325,6 +331,12 @@ def if_up(nic_or_mac):
         _print("FAIL: if_up() - requires nic or mac as argument")
         return None
 
+    # ifup/ifdown scripts are not shipped by default on RHEL-8+
+    if not exists('ifup') and libsan.host.linux.is_installed('NetworkManager'):
+        if not libsan.host.linux.install_package('NetworkManager-initscripts-updown'):
+            print('FAIL: unable to run "ifup" command')
+            return False
+
     if is_mac(nic_or_mac):
         nic = get_nic_of_mac(nic_or_mac)
     else:
@@ -335,12 +347,56 @@ def if_up(nic_or_mac):
     return False
 
 
-def set_ifcfg(nic_or_mac, **kwargs):
+def iface_up(nic_or_mac):
+    """
+    Bring the interface up
+    Parameters:
+    \t Interface name or it's MAC address
+    """
+    if not nic_or_mac:
+        _print("FAIL: iface_up() - requires nic or mac as argument")
+        return False
+
+    if is_mac(nic_or_mac):
+        nic = get_nic_of_mac(nic_or_mac)
+    else:
+        nic = nic_or_mac
+
+    retcode, output = run("ip link set %s up" % nic, return_output=True)
+    if retcode != 0:
+        print(output)
+        return False
+    return True
+
+
+def iface_down(nic_or_mac):
+    """
+    Bring the interface down
+    Parameters:
+    \t Interface name or it's MAC address
+    """
+    if not nic_or_mac:
+        _print("FAIL: iface_down() - requires nic or mac as argument")
+        return False
+
+    if is_mac(nic_or_mac):
+        nic = get_nic_of_mac(nic_or_mac)
+    else:
+        nic = nic_or_mac
+
+    retcode, output = run("ip link set %s down" % nic, return_output=True)
+    if retcode != 0:
+        print(output)
+        return False
+    return True
+
+
+def set_ifcfg(nic_or_mac, parameters):
     """
     Edit or create ifcfg files: IP, prefix, gateway, defroute...
     Parameters:
     \t nic_or_mac: interface name or mac address
-    \t key=value: e.g. IPADDR='10.37.151.7'
+    \t dict of params: e.g. {'IPADDR': '10.37.151.7'}
     """
 
     if is_mac(nic_or_mac):
@@ -351,18 +407,7 @@ def set_ifcfg(nic_or_mac, **kwargs):
     else:
         nic = nic_or_mac
 
-    aug = augeas.Augeas()
-    ifcfg = '/files/etc/sysconfig/network-scripts/ifcfg-' + nic + '/'
-    if kwargs is not None:
-        for key in kwargs:
-            print("INFO: Setting %s to %s for %s" % (key, kwargs[key], nic))
-            aug.set(ifcfg + key, kwargs[key])
-
-    try:
-        aug.save()
-    except augeas.AugeasIOError:
-        print('FAIL: unable to save changes in ' + ifcfg)
-        return False
+    libsan.host.linux.aug_set_config('/etc/sysconfig/network-scripts/ifcfg-' + nic, parameters)
 
     if_down(nic)
     if_up(nic)
