@@ -401,6 +401,9 @@ def scsi_driver_of_host_id(host_id):
         pci_id = pci_id_of_host_id(host_id)
         if pci_id:
             lspci_regex = r"Kernel modules:\s+(\S+)"
+            if run("which lspci", verbose=False) != 0:
+                _print("FAIL: pciutils is not installed. Can't query driver name using pci_id.")
+                return None
             _, output = run("lspci -s \"%s\" -v | grep \"Kernel modules:\"" % pci_id, return_output=True, verbose=False)
             if output:
                 m = re.search(lspci_regex, output)
